<!-- markdownlint-disable -->

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/osmpbf/__init__.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `osmpbf`






---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/osmpbf/__init__.py"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `Node`
Node(id, tags, lonlat) 





---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/osmpbf/__init__.py"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `Relation`
Relation(id, tags, members) 





---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/osmpbf/__init__.py"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>class</kbd> `Way`
Way(id, tags, refs) 





